# Generated by Django 4.2.23 on 2025-08-28 07:46

from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('aa_bb', '0069_tickettoolconfig_ticket_counter'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='tickettoolconfig',
            name='Role_ID',
        ),
        migrations.AddField(
            model_name='tickettoolconfig',
            name='afk_check_enabled',
            field=models.BooleanField(default=False, help_text='Do you want to check if the user logs into the game??'),
        ),
        migrations.AddField(
            model_name='tickettoolconfig',
            name='corp_check_enabled',
            field=models.BooleanField(default=False, help_text='Do you want to check for corp auth compliance?'),
        ),
        migrations.AddField(
            model_name='tickettoolconfig',
            name='discord_check_enabled',
            field=models.BooleanField(default=False, help_text='Do you want to check for discord activity?'),
        ),
        migrations.AddField(
            model_name='tickettoolconfig',
            name='excluded_users',
            field=models.ManyToManyField(blank=True, help_text='List of users to ignore when checking for compliance', related_name='excluded_users', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='tickettoolconfig',
            name='lawn_check_enabled',
            field=models.BooleanField(default=False, help_text='Do you want to check for lawn auth compliance?'),
        ),
        migrations.AddField(
            model_name='tickettoolconfig',
            name='paps_check_enabled',
            field=models.BooleanField(default=False, help_text='Do you want to check for pap requirement compliance?'),
        ),
        migrations.AddField(
            model_name='tickettoolconfig',
            name='staff_roles',
            field=models.TextField(blank=True, help_text='Comma-separated list of staff role IDs allowed on tickets'),
        ),
    ]
