# Generated by Django 4.2.20 on 2025-04-13 12:04

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='General',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
            ],
            options={
                'permissions': (('basic_access', 'Can access this app'), ('full_access', 'Can view all main characters'), ('recruiter_access', 'Can view guest main characters only')),
                'managed': False,
                'default_permissions': (),
            },
        ),
    ]
