# Generated by Django 4.2.23 on 2025-08-27 07:55

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('authentication', '0024_alter_userprofile_language'),
        ('aa_bb', '0061_remove_papsconfig_cap_group_and_more'),
    ]

    operations = [
        migrations.CreateModel(
            name='ComplianceTicket',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('discord_user_id', models.BigIntegerField()),
                ('discord_channel_id', models.BigIntegerField(blank=True, null=True)),
                ('reason', models.CharField(choices=[('trpr', 'TRPR Compliance'), ('lawn', 'LAWN Compliance'), ('paps', 'PAP Requirements'), ('afk', 'Inactivity')], max_length=20)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('last_reminder_sent', models.IntegerField(default=0)),
                ('is_resolved', models.BooleanField(default=False)),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='authentication.userprofile')),
            ],
        ),
    ]
