# Generated by Django 4.2.20 on 2025-05-01 18:54

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aa_bb', '0012_id_types'),
    ]

    operations = [
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='mail_keywords',
            field=models.TextField(blank=True, default='abus,agent,argument,attack,asset,awol,awox,ban,bait,backstab,betray,bully,ccp,cloak,compliance,complicit,cover,defect,defraud,disloyal,dummy,espion,eula,fake,flag,freeload,grift,harass,inactiv,infiltra,info,insider,intel,kick,kill,launder,leak,leave,left,malign,mercena,mission,mole,ops,offer,phish,propaganda,rebel,resign,rogue,rule,sabot,scam,security,secret,sharing,shitpost,spai,spie,spy,steal,stolen,sus,target,theft,trap,traitor,treason,trust,unreliable,warning', help_text="List red flag keywords to look for in a mail, separated by ','", null=True),
        ),
    ]
