# Generated by Django 4.2.23 on 2025-12-15 17:46

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('authentication', '0024_alter_userprofile_language'),
        ('groupmanagement', '0019_adding_restricted_to_groups'),
        ('django_celery_beat', '0019_alter_periodictasks_options'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('aa_bb', '0089_bigbrotherconfig_asset_notify_and_more'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='papsconfig',
            options={'verbose_name': 'PAPs/AFAT Configuration', 'verbose_name_plural': 'PAPs/AFAT Configuration'},
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='are_daily_messages_active',
            field=models.BooleanField(default=False, help_text='are daily messages activated/deactivated?', verbose_name='Daily Messages Active?'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='are_opt_messages1_active',
            field=models.BooleanField(default=False, help_text='are optional messages 1 activated/deactivated?', verbose_name='Optional Messages 1 Activated?'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='are_opt_messages2_active',
            field=models.BooleanField(default=False, help_text='are optional messages 2 activated/deactivated?', verbose_name='Optional Messages 2 Activated?'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='are_opt_messages3_active',
            field=models.BooleanField(default=False, help_text='are optional messages 3 activated/deactivated?', verbose_name='Optional Messages 3 Activated?'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='are_opt_messages4_active',
            field=models.BooleanField(default=False, help_text='are optional messages 4 activated/deactivated?', verbose_name='Optional Messages 4 Activated?'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='are_opt_messages5_active',
            field=models.BooleanField(default=False, help_text='are optional messages 5 activated/deactivated?', verbose_name='Optional Messages 5 Activated?'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='are_recurring_stats_active',
            field=models.BooleanField(default=False, help_text='Are recurring stats posts activated/deactivated?', verbose_name='Recurring Stats Active?'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='asset_notify',
            field=models.BooleanField(default=True, help_text='Whether to send Asset Change notifications to discord', verbose_name='Hostile Asset Location Change Discord Notifications'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='awox_notify',
            field=models.BooleanField(default=True, help_text='Whether to send AWOX notificaitons to discord', verbose_name='AWOX Discord Notifications'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='bb_guest_states',
            field=models.ManyToManyField(blank=True, help_text='List of states to be considered guests', related_name='bb_guest_states_configs', to='authentication.state', verbose_name='Guest States'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='bb_member_states',
            field=models.ManyToManyField(blank=True, help_text='List of states to be considered members', related_name='bb_member_states_configs', to='authentication.state', verbose_name='Member States'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='character_scopes',
            field=models.TextField(default='publicData,esi-calendar.read_calendar_events.v1,esi-location.read_location.v1,esi-location.read_ship_type.v1,esi-mail.read_mail.v1,esi-skills.read_skills.v1,esi-skills.read_skillqueue.v1,esi-wallet.read_character_wallet.v1,esi-search.search_structures.v1,esi-clones.read_clones.v1,esi-characters.read_contacts.v1,esi-universe.read_structures.v1,esi-killmails.read_killmails.v1,esi-assets.read_assets.v1,esi-fleets.read_fleet.v1,esi-fleets.write_fleet.v1,esi-ui.open_window.v1,esi-ui.write_waypoint.v1,esi-fittings.read_fittings.v1,esi-characters.read_loyalty.v1,esi-characters.read_standings.v1,esi-industry.read_character_jobs.v1,esi-markets.read_character_orders.v1,esi-characters.read_corporation_roles.v1,esi-location.read_online.v1,esi-contracts.read_character_contracts.v1,esi-clones.read_implants.v1,esi-characters.read_fatigue.v1,esi-characters.read_notifications.v1,esi-industry.read_character_mining.v1,esi-characters.read_titles.v1', help_text='Comma-separated list of required character scopes', verbose_name='Character Scopes'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='clone_notify',
            field=models.BooleanField(default=True, help_text='Whether to send Clone State Change notifications to discord', verbose_name='Hostile Jump Clone Location Change Discord Notifications'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='consider_all_structures_hostile',
            field=models.BooleanField(default=False, help_text="Consider all player owned structures that are not listed as 'whitelist, ignored or member' as hostile?", verbose_name='Consider Citadels as Hostile'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='consider_npc_stations_hostile',
            field=models.BooleanField(default=False, help_text='Consider assets in any non-player owned (NPC) station as hostile?', verbose_name='Consider NPC Stations as Hostile'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='consider_nullsec_hostile',
            field=models.BooleanField(default=False, help_text='Consider all nullsec regions as hostile?', verbose_name='Consider Nullsec as Hostile'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='contact_notify',
            field=models.BooleanField(default=True, help_text='Whether to send Contact Change notifications to discord', verbose_name='Hostile Contact Change Discord Notifications'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='contract_notify',
            field=models.BooleanField(default=True, help_text='Whether to send Contract Change notifications to discord', verbose_name='Hostile Contract Discord Notifications'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='corporation_scopes',
            field=models.TextField(default='esi-corporations.read_corporation_membership.v1,esi-corporations.read_structures.v1,esi-killmails.read_corporation_killmails.v1,esi-corporations.track_members.v1,esi-wallet.read_corporation_wallets.v1,esi-corporations.read_divisions.v1,esi-assets.read_corporation_assets.v1,esi-corporations.read_titles.v1,esi-contracts.read_corporation_contracts.v1,esi-corporations.read_starbases.v1,esi-industry.read_corporation_jobs.v1,esi-markets.read_corporation_orders.v1,esi-industry.read_corporation_mining.v1,esi-planets.read_customs_offices.v1,esi-search.search_structures.v1,esi-universe.read_structures.v1,esi-characters.read_corporation_roles.v1', help_text='Comma-separated list of required corporation scopes', verbose_name='Corporation Scopes'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='ct_notify',
            field=models.BooleanField(default=True, help_text='Whether to send CT audit completion notifications to discord', verbose_name='CorpTool Audit Completion Discord Notifications'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='cyno_notify',
            field=models.BooleanField(default=True, help_text='Whether to send Cyno Change notifications to discord', verbose_name='Cyno ship and skill Discord Notifications'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='dailyschedule',
            field=models.ForeignKey(blank=True, help_text='schedule for daily messages', null=True, on_delete=django.db.models.deletion.CASCADE, related_name='bigbrother_dailyschedule', to='django_celery_beat.crontabschedule', verbose_name='Daily Message Schedule'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='dailywebhook',
            field=models.URLField(blank=True, help_text='Discord webhook for sending daily messages', null=True, verbose_name='Daily Message Discord Webhook'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='dlc_are_recurring_stats_active',
            field=models.BooleanField(default=False, help_text='Read-only flag showing if the recurring stats posts activated/deactivated.', verbose_name='Recurring Stats Active?'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='dlc_corp_brother_active',
            field=models.BooleanField(default=False, help_text='Read-only flag showing if the Corp Brother module is enabled for this token.', verbose_name='Corp Brother Active?'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='dlc_daily_messages_active',
            field=models.BooleanField(default=False, help_text='Read-only flag showing if the Daily Messages module is enabled for this token.', verbose_name='Daily Messages Active?'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='dlc_loa_active',
            field=models.BooleanField(default=False, help_text='Read-only flag showing if the Leave of Absence module is enabled for this token.', verbose_name='Leave of Absence Active?'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='dlc_pap_active',
            field=models.BooleanField(default=False, help_text='Read-only flag showing if the PAP module is enabled for this token.', verbose_name='PAP/AFAT Active?'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='dlc_reddit_active',
            field=models.BooleanField(default=False, help_text='Read-only flag showing if the Reddit module is enabled for this token.', verbose_name='Reddit Plugin Active?'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='dlc_tickets_active',
            field=models.BooleanField(default=False, help_text='Read-only flag showing if the Tickets module is enabled for this token.', verbose_name='Ticket System Active?'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='everyone_messages',
            field=models.ManyToManyField(blank=True, help_text='List of message types that should ping @everyone', related_name='everyone_configs', to='aa_bb.messagetype', verbose_name='@everyone Alert Conditions'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='excluded_stations',
            field=models.TextField(blank=True, help_text="List of station/structure IDs excluded from hostile checks, separated by ','", null=True, verbose_name='Excluded Stations'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='excluded_systems',
            field=models.TextField(blank=True, help_text="List of system IDs excluded from hostile checks, separated by ','", null=True, verbose_name='Excluded Systems'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='here_messages',
            field=models.ManyToManyField(blank=True, help_text='List of message types that should ping @here', related_name='here_configs', to='aa_bb.messagetype', verbose_name='@here Alert Conditions'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='hostile_alliances',
            field=models.TextField(blank=True, default='', help_text="List of alliance IDs considered hostile, separated by ','", null=True, verbose_name='Hostile Alliances'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='hostile_assets_ships_only',
            field=models.BooleanField(default=False, help_text='Only consider ship assets when checking and rendering hostile asset locations?', verbose_name='Only Consider Ships as Hostile Assets'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='hostile_corporations',
            field=models.TextField(blank=True, help_text="List of corporation IDs considered hostile, separated by ','", null=True, verbose_name='Hostile Corporations'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='ignored_corporations',
            field=models.TextField(blank=True, help_text="List of corporation IDs to be ignored in the corp brother task and to not show up in Corp Brother tab, separated by ','", null=True, verbose_name='Ignored Corporations'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='is_active',
            field=models.BooleanField(default=False, editable=False, help_text='has the plugin been activated/deactivated?', verbose_name='Active?'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='is_loa_active',
            field=models.BooleanField(default=False, help_text='has the Leave of Absence module been activated/deactivated? (You will need to restart AA for this to take effect)', verbose_name='Leave of Absence Active?'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='is_paps_active',
            field=models.BooleanField(default=False, help_text='has the PAP/AFAT stats module been activated/deactivated? (You will need to restart AA for this to take effect)', verbose_name='PAP/AFAT Stats Active?'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='is_warmer_active',
            field=models.BooleanField(default=True, help_text='has the Cache warmer feature been activated/deactivated? (You need it if you have a gunicorn timeout set in your supervisor.conf, if you want to disable it, set the timeout to 0 first)', verbose_name='Cache Warmer Active?'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='loa_max_logoff_days',
            field=models.IntegerField(default=30, help_text='How many days can a user not login w/o a loa request before notifications', verbose_name='Max Days before needing LOA'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='loawebhook',
            field=models.URLField(blank=True, help_text='Discord webhook for sending Leave of Absence', null=True, verbose_name='Leave of Absence Discord WebHhok'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='mail_notify',
            field=models.BooleanField(default=True, help_text='Whether to send Suspicious Mail notifications to discord', verbose_name='Suspicious Mail Notifications'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='main_alliance',
            field=models.TextField(default=123456789, editable=False, help_text='Your Alliance', verbose_name='Main Alliance'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='main_alliance_id',
            field=models.PositiveIntegerField(default=123456789, editable=False, help_text='Your Alliance ID', verbose_name='Main Alliance ID'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='main_corporation',
            field=models.TextField(default=0, editable=False, help_text='Your Corporation', verbose_name='Main Corporation'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='main_corporation_id',
            field=models.BigIntegerField(default=0, editable=False, help_text='Your Corporation Id', verbose_name='Main Corporation ID'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='member_alliances',
            field=models.TextField(blank=True, help_text="List of alliance IDs to be considered members, separated by ','", null=True, verbose_name='Member Alliances'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='member_corporations',
            field=models.TextField(blank=True, help_text="List of corporation IDs to be considered members, separated by ','", null=True, verbose_name='Member Corporations'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='new_user_notify',
            field=models.BooleanField(default=False, help_text='Whether to send notifications of all previous user history when a user first gets audited, this can be VERY spammy on a first time load of the tool', verbose_name='New User Notifications'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='optschedule1',
            field=models.ForeignKey(blank=True, help_text='schedule for optional messages 1', null=True, on_delete=django.db.models.deletion.CASCADE, related_name='bigbrother_optschedule1', to='django_celery_beat.crontabschedule', verbose_name='Optional Messages #1 Schedule'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='optschedule2',
            field=models.ForeignKey(blank=True, help_text='schedule for optional messages 2', null=True, on_delete=django.db.models.deletion.CASCADE, related_name='bigbrother_optschedule2', to='django_celery_beat.crontabschedule', verbose_name='Optional Messages #2 Schedule'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='optschedule3',
            field=models.ForeignKey(blank=True, help_text='schedule for optional messages 3', null=True, on_delete=django.db.models.deletion.CASCADE, related_name='bigbrother_optschedule3', to='django_celery_beat.crontabschedule', verbose_name='Optional Messages #3 Schedule'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='optschedule4',
            field=models.ForeignKey(blank=True, help_text='schedule for optional messages 4', null=True, on_delete=django.db.models.deletion.CASCADE, related_name='bigbrother_optschedule4', to='django_celery_beat.crontabschedule', verbose_name='Optional Messages #4 Schedule'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='optschedule5',
            field=models.ForeignKey(blank=True, help_text='schedule for optional messages 5', null=True, on_delete=django.db.models.deletion.CASCADE, related_name='bigbrother_optschedule5', to='django_celery_beat.crontabschedule', verbose_name='Optional Messages #5 Schedule'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='optwebhook1',
            field=models.URLField(blank=True, help_text='Discord webhook for sending optional messages 1', null=True, verbose_name='Optional Messages #1 Discord Webhook'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='optwebhook2',
            field=models.URLField(blank=True, help_text='Discord webhook for sending optional messages 2', null=True, verbose_name='Optional Messages #2 Discord Webhook'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='optwebhook3',
            field=models.URLField(blank=True, help_text='Discord webhook for sending optional messages 3', null=True, verbose_name='Optional Messages #3 Discord Webhook'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='optwebhook4',
            field=models.URLField(blank=True, help_text='Discord webhook for sending optional messages 4', null=True, verbose_name='Optional Messages #4 Discord Webhook'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='optwebhook5',
            field=models.URLField(blank=True, help_text='Discord webhook for sending optional messages 5', null=True, verbose_name='Optional Messages #5 Discord Webhook'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='pingrole1_messages',
            field=models.ManyToManyField(blank=True, help_text='List of message types that should ping the pingrole1', related_name='pingrole1_configs', to='aa_bb.messagetype', verbose_name='Pingrole1 Alert Conditions'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='pingrole2_messages',
            field=models.ManyToManyField(blank=True, help_text='List of message types that should ping the pingrole2', related_name='pingrole2_configs', to='aa_bb.messagetype', verbose_name='Pingrole2 Alert Conditions'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='pingroleID',
            field=models.CharField(default=0, help_text='Input the role ID you want pinged when people need to investigate', max_length=255, null=True, verbose_name='Pinged Role ID #1'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='pingroleID2',
            field=models.CharField(default=0, help_text='Input the 2nd role ID you want pinged when people need to investigate', max_length=255, null=True, verbose_name='Pinged Role ID #2'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='sp_inject_notify',
            field=models.BooleanField(default=True, help_text='Whether to send SP Injection notifications to discord', verbose_name='Skill Point Injection Discord Notifications'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='stats_schedule',
            field=models.ForeignKey(blank=True, help_text='Schedule for recurring stats posts.', null=True, on_delete=django.db.models.deletion.CASCADE, related_name='bigbrother_stats_schedule', to='django_celery_beat.crontabschedule', verbose_name='Recurring Stats Schedule'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='stats_webhook',
            field=models.URLField(blank=True, help_text='Discord webhook for posting recurring stats.', null=True, verbose_name='Recurring Stats Discord Webhook'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='ticket_notify_auto',
            field=models.BooleanField(default=True, help_text='Whether to send ticket resolution notifications when automatically closed to discord', verbose_name='Ticket Closed Automatically Discord Notification'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='ticket_notify_man',
            field=models.BooleanField(default=True, help_text='Whether to send ticket resolution notifications when manually closed to discord', verbose_name='Ticket Closed Manually Discord Notification'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='transaction_notify',
            field=models.BooleanField(default=True, help_text='Whether to send Suspicious Transaction notifications to discord', verbose_name='Suspicious Transaction Notifications'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='webhook',
            field=models.URLField(blank=True, help_text='Discord webhook for sending BB notifications', null=True, verbose_name='Main Discord Webhook'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='whitelist_alliances',
            field=models.TextField(blank=True, default='', help_text="List of alliance IDs considered whitelisted, separated by ','", null=True, verbose_name='Whitelisted Alliances'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='whitelist_corporations',
            field=models.TextField(blank=True, help_text="List of corporation IDs considered whitelisted, separated by ','", null=True, verbose_name='Whitelisted Corporations'),
        ),
        migrations.AlterField(
            model_name='papsconfig',
            name='alliance_modifier',
            field=models.PositiveIntegerField(default=1, help_text='How many PAPs/AFAT is an alliance PAP worth?', verbose_name='Alliance PAPs/AFAT Modifier'),
        ),
        migrations.AlterField(
            model_name='papsconfig',
            name='cap_group',
            field=models.ForeignKey(blank=True, help_text='Select your cap group', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='cap_group', to='groupmanagement.authgroup', verbose_name='Cap Group'),
        ),
        migrations.AlterField(
            model_name='papsconfig',
            name='cap_group_paps',
            field=models.PositiveIntegerField(default=1, help_text='How many PAPs/AFAT to add for being in the cap group', verbose_name='Cap Group PAPs/AFAT Configuration'),
        ),
        migrations.AlterField(
            model_name='papsconfig',
            name='capital_groups_get_paps',
            field=models.BooleanField(default=False, help_text='Does being in corp capital groups give out PAPs/AFAT?', verbose_name='Cap Group PAPs/AFAT Enabled?'),
        ),
        migrations.AlterField(
            model_name='papsconfig',
            name='coalition_modifier',
            field=models.PositiveIntegerField(default=1, help_text='How many PAPs/AFAT is a coalition PAP worth?', verbose_name='Coalition PAPs/AFAT Modifier'),
        ),
        migrations.AlterField(
            model_name='papsconfig',
            name='corp_modifier',
            field=models.PositiveIntegerField(default=1, help_text='How many PAPs/AFAT is a corp PAP worth?', verbose_name='Corp PAPs/AFAT Modifier'),
        ),
        migrations.AlterField(
            model_name='papsconfig',
            name='excluded_groups',
            field=models.ManyToManyField(blank=True, help_text='List of groups which prevent giving PAPs/AFAT', related_name='excluded_groups', to='groupmanagement.authgroup', verbose_name='Excluded Groups'),
        ),
        migrations.AlterField(
            model_name='papsconfig',
            name='excluded_groups_get_paps',
            field=models.BooleanField(default=False, help_text='if user is in a group which prevent other groups from giving PAPs/AFAT, do they get 1x group PAPs/AFAT modifier?', verbose_name='Excluded Groups Modifier'),
        ),
        migrations.AlterField(
            model_name='papsconfig',
            name='excluded_users',
            field=models.ManyToManyField(blank=True, help_text='List of user prevented from getting all PAPs/AFAT', related_name='excluded_user', to=settings.AUTH_USER_MODEL, verbose_name='Excluded Users'),
        ),
        migrations.AlterField(
            model_name='papsconfig',
            name='excluded_users_paps',
            field=models.ManyToManyField(blank=True, help_text='List of user prevented from getting PAPs/AFAT from groups', related_name='excluded_users_paps', to=settings.AUTH_USER_MODEL, verbose_name="Users who don't get PAPs/AFAT from groups"),
        ),
        migrations.AlterField(
            model_name='papsconfig',
            name='group_paps',
            field=models.ManyToManyField(blank=True, help_text='List of groups which give PAPs/AFAT', related_name='group_paps', to='groupmanagement.authgroup', verbose_name='Group that get PAPs/AFAT'),
        ),
        migrations.AlterField(
            model_name='papsconfig',
            name='group_paps_modifier',
            field=models.PositiveIntegerField(default=1, help_text='How many PAPs/AFAT to add per group', verbose_name='Group PAPs/AFAT Modifier'),
        ),
        migrations.AlterField(
            model_name='papsconfig',
            name='max_corp_paps',
            field=models.PositiveIntegerField(default=1, help_text='How many Corp PAPs/AFAT will count?', verbose_name='Corp PAPs/AFAT Maximum'),
        ),
        migrations.AlterField(
            model_name='papsconfig',
            name='required_paps',
            field=models.PositiveIntegerField(default=1, help_text='How many PAPs/AFAT per month should a user get?', verbose_name='Required PAPs/AFAT per month'),
        ),
        migrations.AlterField(
            model_name='papsconfig',
            name='super_group',
            field=models.ForeignKey(blank=True, help_text='Select your super group', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='super_group', to='groupmanagement.authgroup', verbose_name='Super Group'),
        ),
        migrations.AlterField(
            model_name='papsconfig',
            name='super_group_paps',
            field=models.PositiveIntegerField(default=1, help_text='How many PAPs/AFAT to add for being in the super group', verbose_name='Super Group PAPs/AFAT Configuration'),
        ),
        migrations.AlterField(
            model_name='papsconfig',
            name='titan_group',
            field=models.ForeignKey(blank=True, help_text='Select your titan group', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='titan_group', to='groupmanagement.authgroup', verbose_name='Titan Group'),
        ),
        migrations.AlterField(
            model_name='papsconfig',
            name='titan_group_paps',
            field=models.PositiveIntegerField(default=1, help_text='How many PAPs/AFAT to add for being in the titan group', verbose_name='Titan Group PAPs/AFAT Configuration'),
        ),
    ]
