# Generated by Django 4.2.23 on 2025-08-18 11:50

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aa_bb', '0047_bigbrotherconfig_member_alliances'),
    ]

    operations = [
        migrations.CreateModel(
            name='CharacterAccountState',
            fields=[
                ('char_id', models.BigIntegerField(primary_key=True, serialize=False)),
                ('skill_used', models.BigIntegerField(blank=True, null=True)),
                ('state', models.CharField(choices=[('alpha', 'Alpha'), ('omega', 'Omega'), ('unknown', 'Unknown')], max_length=10)),
            ],
        ),
    ]
