# Generated by Django 4.2.23 on 2026-01-05 21:51

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aa_bb', '0102_remove_tickettoolconfig_use_forum_threads_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='tickettoolconfig',
            name='afk_check_include_user',
            field=models.BooleanField(default=True, help_text='Include the user in the ticket (Discord channel/thread).'),
        ),
        migrations.AddField(
            model_name='tickettoolconfig',
            name='awox_kill_include_user',
            field=models.BooleanField(default=True, help_text='Include the user in the ticket (Discord channel/thread).'),
        ),
        migrations.AddField(
            model_name='tickettoolconfig',
            name='char_removed_include_user',
            field=models.BooleanField(default=True, help_text='Include the user in the ticket (Discord channel/thread).'),
        ),
        migrations.AddField(
            model_name='tickettoolconfig',
            name='corp_check_include_user',
            field=models.BooleanField(default=True, help_text='Include the user in the ticket (Discord channel/thread).'),
        ),
        migrations.AddField(
            model_name='tickettoolconfig',
            name='discord_check_include_user',
            field=models.BooleanField(default=True, help_text='Include the user in the ticket (Discord channel/thread).'),
        ),
        migrations.AddField(
            model_name='tickettoolconfig',
            name='discord_inactivity_include_user',
            field=models.BooleanField(default=True, help_text='Include the user in the ticket (Discord channel/thread).'),
        ),
        migrations.AddField(
            model_name='tickettoolconfig',
            name='paps_check_include_user',
            field=models.BooleanField(default=True, help_text='Include the user in the ticket (Discord channel/thread).'),
        ),
        migrations.AlterField(
            model_name='tickettoolconfig',
            name='discord_inactivity_reason',
            field=models.TextField(blank=True, default='<@&{role}>,{namee}, has been inactive on Discord for over {days} day(s).', help_text='Message to send with {role}, {namee} and {days} variables', null=True),
        ),
        migrations.AlterField(
            model_name='tickettoolconfig',
            name='paps_check_enabled',
            field=models.BooleanField(default=False, help_text='If enabled, checks if the user has met the minimum PAP/AFAT requirements (Integration with aa-afat).'),
        ),
    ]
