# Generated by Django 4.2.23 on 2025-12-17 15:38

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('eveonline', '0017_alliance_and_corp_names_are_not_unique'),
        ('aa_bb', '0090_alter_papsconfig_options_and_more'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='bigbrotherconfig',
            name='dlc_are_recurring_stats_active',
        ),
        migrations.RemoveField(
            model_name='bigbrotherconfig',
            name='dlc_corp_brother_active',
        ),
        migrations.RemoveField(
            model_name='bigbrotherconfig',
            name='dlc_daily_messages_active',
        ),
        migrations.RemoveField(
            model_name='bigbrotherconfig',
            name='dlc_loa_active',
        ),
        migrations.RemoveField(
            model_name='bigbrotherconfig',
            name='dlc_pap_active',
        ),
        migrations.RemoveField(
            model_name='bigbrotherconfig',
            name='dlc_reddit_active',
        ),
        migrations.RemoveField(
            model_name='bigbrotherconfig',
            name='dlc_tickets_active',
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='auto_import_contacts_enabled',
            field=models.BooleanField(default=False, help_text='If enabled, BigBrother will periodically read aa-contacts standings and merge them into member/hostile corp/alliance lists.', verbose_name='Auto-import standings from aa-contacts'),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='contacts_handle_neutrals',
            field=models.CharField(choices=[('hostile', 'Handle neutrals as hostile'), ('whitelist', 'Handle neutrals as whitelisted'), ('ignore', 'Do nothing with neutrals')], default='ignore', help_text="Controls how BigBrother treats aa-contacts with neutral (0) standing. 'Hostile' = treat neutrals as hostile, 'Whitelist' = treat neutrals as whitelisted/ignored, 'Ignore' = leave neutrals unchanged.", max_length=16),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='contacts_import_cache',
            field=models.JSONField(blank=True, default=dict, help_text='Internal cache of IDs imported from aa-contacts so that removed contacts can be pruned without touching manually added hostiles / members / whitelists.'),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='contacts_source_alliances',
            field=models.ManyToManyField(blank=True, help_text='Alliances whose aa-contacts standings should be imported. Alliances with positive standing become members; negative standing become hostile; zero is ignored.', related_name='bb_contacts_source_configs', to='eveonline.eveallianceinfo', verbose_name='aa-contacts source alliance'),
        ),
    ]
