"""Initialize the app"""
from django.utils.translation import gettext_lazy as _

__version__ = "3.2.7b6"
__title__ = "BigBrother"
__title_translated__ = _("BigBrother")

__esi_compatibility_date__ = "2025-11-06"

__package_name__ = "aa_bb"
__app_name__ = "aa_bb"
__app_name_verbose__ = "Alliance Auth BigBrother"
__app_name_useragent__ = "AA-BigBrother"

__github_url__ = f"https://github.com/BroodLK/{__package_name__}"
