# Generated by Django 4.2.23 on 2025-08-20 13:29

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('auth', '0012_alter_user_first_name_max_length'),
        ('aa_bb', '0054_alter_general_options'),
    ]

    operations = [
        migrations.AddField(
            model_name='papsconfig',
            name='group_paps',
            field=models.ManyToManyField(blank=True, help_text='List of groups which give paps', related_name='bb_guest_states_configs', to='auth.group'),
        ),
        migrations.AddField(
            model_name='papsconfig',
            name='group_paps_modifier',
            field=models.PositiveIntegerField(default=1, help_text='How many PAPs to add per group'),
        ),
    ]
