# Generated by Django 4.2.23 on 2026-01-08 14:35

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aa_bb', '0103_tickettoolconfig_afk_check_include_user_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='is_active',
            field=models.BooleanField(default=True, help_text='has the plugin been activated/deactivated?', verbose_name='Active?'),
        ),
        migrations.AlterField(
            model_name='tickettoolconfig',
            name='staff_roles',
            field=models.TextField(blank=True,
                                   help_text='Comma-separated list of staff role IDs or names allowed on tickets'),
        ),
    ]
