# Generated by Django 4.2.26 on 2025-11-15 17:36

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aa_bb', '0080_bigbrotherconfig_dlc_flags'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='papsconfig',
            name='imp_modifier',
        ),
        migrations.RemoveField(
            model_name='papsconfig',
            name='lawn_modifier',
        ),
        migrations.RemoveField(
            model_name='tickettoolconfig',
            name='lawn_check',
        ),
        migrations.RemoveField(
            model_name='tickettoolconfig',
            name='lawn_check_enabled',
        ),
        migrations.RemoveField(
            model_name='tickettoolconfig',
            name='lawn_check_frequency',
        ),
        migrations.RemoveField(
            model_name='tickettoolconfig',
            name='lawn_check_reason',
        ),
        migrations.RemoveField(
            model_name='tickettoolconfig',
            name='lawn_check_reminder',
        ),
        migrations.AddField(
            model_name='papsconfig',
            name='alliance_modifier',
            field=models.PositiveIntegerField(default=1, help_text='How many PAPs is an alliance PAP worth?'),
        ),
        migrations.AddField(
            model_name='papsconfig',
            name='coalition_modifier',
            field=models.PositiveIntegerField(default=1, help_text='How many PAPs is a coalition PAP worth?'),
        ),
        migrations.AlterField(
            model_name='complianceticket',
            name='reason',
            field=models.CharField(choices=[('corp_check', 'Corp Compliance'), ('paps_check', 'PAP Requirements'), ('afk_check', 'Inactivity'), ('discord_check', 'User is not on discord'), {'char_removed', 'Character removed'}, {'awox_kill', 'AWOX kill found'}], max_length=20),
        ),
    ]
