# Generated by Django 4.2.23 on 2025-11-20 21:31

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('aa_bb', '0082_remove_bigbrotherconfig_token_and_more'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='bigbrotherredditmessage',
            options={'ordering': ['-created'], 'verbose_name': 'Reddit Recruitment Message', 'verbose_name_plural': 'Reddit Recruitment Messages'},
        ),
        migrations.AlterModelOptions(
            name='bigbrotherredditsettings',
            options={'verbose_name': 'BigBrother Reddit Settings'},
        ),
        migrations.AlterModelOptions(
            name='complianceticket',
            options={'ordering': ['-created_at'], 'verbose_name': 'Compliance Ticket', 'verbose_name_plural': 'Compliance Tickets'},
        ),
        migrations.AlterModelOptions(
            name='leaverequest',
            options={'ordering': ['-created_at'], 'verbose_name': 'Leave of Absence Request', 'verbose_name_plural': 'Leave of Absence Requests'},
        ),
        migrations.AlterModelOptions(
            name='optmessages1',
            options={'verbose_name': 'Optional Message 1', 'verbose_name_plural': 'Optional Messages 1'},
        ),
        migrations.AlterModelOptions(
            name='optmessages2',
            options={'verbose_name': 'Optional Message 2', 'verbose_name_plural': 'Optional Messages 2'},
        ),
        migrations.AlterModelOptions(
            name='optmessages3',
            options={'verbose_name': 'Optional Message 3', 'verbose_name_plural': 'Optional Messages 3'},
        ),
        migrations.AlterModelOptions(
            name='optmessages4',
            options={'verbose_name': 'Optional Message 4', 'verbose_name_plural': 'Optional Messages 4'},
        ),
        migrations.AlterModelOptions(
            name='optmessages5',
            options={'verbose_name': 'Optional Message 5', 'verbose_name_plural': 'Optional Messages 5'},
        ),
        migrations.AlterModelOptions(
            name='papcompliance',
            options={'verbose_name': 'PAP Compliance Score', 'verbose_name_plural': 'PAP Compliance Scores'},
        ),
        migrations.AlterModelOptions(
            name='tickettoolconfig',
            options={'verbose_name': 'Ticket Tool Configuration', 'verbose_name_plural': 'Ticket Tool Configuration'},
        ),
        migrations.AlterModelOptions(
            name='warmprogress',
            options={'verbose_name': 'Warm Preload Progress', 'verbose_name_plural': 'Warm Preload Progress'},
        ),
        migrations.RenameField(
            model_name='userstatus',
            old_name='has_imp_blacklist',
            new_name='has_alliance_blacklist',
        ),
        migrations.RenameField(
            model_name='userstatus',
            old_name='has_lawn_blacklist',
            new_name='has_coalition_blacklist',
        ),
    ]
