<!--
  Base layout for the Leave of Absence (LOA) interface.
  Injects the LOA nav menu into the AA header and exposes a `details` block
  so individual LOA views only render their main panel.
-->
{% extends 'allianceauth/base-bs5.html' %}

{% load i18n %}

{% block page_title %}
    {% translate "Leave of Absence" %}
{% endblock %}

{% block header_nav_collapse_left %}
    {% include 'loa/menu.html' %}
{% endblock %}

{% block content %}
    <div class="loa">
        {% block details %}{% endblock %}
    </div>
{% endblock %}
