# Generated by Django 4.2.23 on 2025-08-17 18:42

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aa_bb', '0046_bigbrotherconfig_member_corporations'),
    ]

    operations = [
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='member_alliances',
            field=models.TextField(blank=True, help_text="List of alliance IDs to be considered members, separated by ','", null=True),
        ),
    ]
