# Generated by Django 4.2.21 on 2025-08-03 12:00

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aa_bb', '0018_userstatus_cyno_userstatus_has_skills_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='whitelist_alliances',
            field=models.TextField(blank=True, default='', help_text="List of alliance IDs considered whitelisted, separated by ','", null=True),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='whitelist_corporations',
            field=models.TextField(blank=True, help_text="List of corporation IDs considered whitelisted, separated by ','", null=True),
        ),
    ]
