# Generated by Django 4.2.20 on 2025-05-02 08:08

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('aa_bb', '0013_bigbrotherconfig_mail_keywords'),
    ]

    operations = [
        migrations.CreateModel(
            name='ProcessedContract',
            fields=[
                ('contract_id', models.BigIntegerField(help_text="The Contract.contract_id that we've processed", primary_key=True, serialize=False)),
                ('processed_at', models.DateTimeField(auto_now_add=True, help_text='When we first processed this contract')),
            ],
            options={
                'verbose_name': 'Processed Contract',
                'verbose_name_plural': 'Processed Contracts',
                'db_table': 'aa_bb_processed_contracts',
            },
        ),
        migrations.CreateModel(
            name='ProcessedMail',
            fields=[
                ('mail_id', models.BigIntegerField(help_text="The MailMessage.id_key that we've processed", primary_key=True, serialize=False)),
                ('processed_at', models.DateTimeField(auto_now_add=True, help_text='When we first processed this mail')),
            ],
            options={
                'verbose_name': 'Processed Mail',
                'verbose_name_plural': 'Processed Mails',
                'db_table': 'aa_bb_processed_mails',
            },
        ),
        migrations.RemoveField(
            model_name='bigbrotherconfig',
            name='mail_keywords',
        ),
        migrations.CreateModel(
            name='SusMailNote',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('user_id', models.BigIntegerField(help_text='The AllianceAuth user ID who owns these characters')),
                ('note', models.TextField(help_text='The summary string of flags for this mail')),
                ('created', models.DateTimeField(auto_now_add=True, help_text='When this note was created')),
                ('updated', models.DateTimeField(auto_now=True, help_text='When this note was last updated')),
                ('mail', models.OneToOneField(help_text='The mail this note refers to', on_delete=django.db.models.deletion.CASCADE, to='aa_bb.processedmail')),
            ],
            options={
                'verbose_name': 'Suspicious Mail Note',
                'verbose_name_plural': 'Suspicious Mail Notes',
                'db_table': 'aa_bb_sus_mail_notes',
            },
        ),
        migrations.CreateModel(
            name='SusContractNote',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('user_id', models.BigIntegerField(help_text='The AllianceAuth user ID who owns these characters')),
                ('note', models.TextField(help_text='The summary string of flags for this contract')),
                ('created', models.DateTimeField(auto_now_add=True, help_text='When this note was created')),
                ('updated', models.DateTimeField(auto_now=True, help_text='When this note was last updated')),
                ('contract', models.OneToOneField(help_text='The contract this note refers to', on_delete=django.db.models.deletion.CASCADE, to='aa_bb.processedcontract')),
            ],
            options={
                'verbose_name': 'Suspicious Contract Note',
                'verbose_name_plural': 'Suspicious Contract Notes',
                'db_table': 'aa_bb_sus_contract_notes',
            },
        ),
    ]
