# Generated by Django 4.2.21 on 2026-01-08 (Manual migration for consider_lowsec_hostile)

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aa_bb', '0105_remove_tickettoolconfig_compliance_filter'),
    ]

    operations = [
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='consider_lowsec_hostile',
            field=models.BooleanField(default=False, help_text='Consider all lowsec regions as hostile?', verbose_name='Consider Lowsec as Hostile'),
        ),
    ]
