# Generated by Django 4.2.23 on 2026-01-02 23:08

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aa_bb', '0098_bigbrotherconfig_exclude_high_sec_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='tickettoolconfig',
            name='hr_forum_webhook',
            field=models.URLField(blank=True, help_text='Discord webhook for creating forum threads for compliance issues (Fallback if discordbot is not installed)', null=True, verbose_name='HR Forum Webhook'),
        ),
    ]
