# Generated by Django 4.2.23 on 2025-08-05 10:15

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aa_bb', '0026_alter_general_options_alter_bigbrotherconfig_id_and_more'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='general',
            options={'default_permissions': (), 'managed': False, 'permissions': (('basic_access', 'Can access this app'), ('full_access', 'Can view all main characters'), ('recruiter_access', 'Can view guest main characters only'), ('can_blacklist_characters', 'Can add characters to blacklist'), ('can_access_loa', 'Can submit a Leave Of Absence request'), ('can_view_all_loa', 'Can view all Leave Of Absence requests'), ('can_manage_loa', 'Can manage Leave Of Absence requests'))},
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='is_loa_active',
            field=models.BooleanField(default=False, help_text='has the Leave of Absence module been activated/deactivated?'),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='loawebhook',
            field=models.URLField(blank=True, help_text='Discord webhook for sending Leave of Absence', null=True),
        ),
    ]
