# Generated by Django 4.2.23 on 2025-08-05 10:48

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aa_bb', '0028_alter_bigbrotherconfig_is_loa_active'),
    ]

    operations = [
        migrations.AddField(
            model_name='leaverequest',
            name='main_character',
            field=models.CharField(blank=True, help_text="The user's primary character when they made the request", max_length=100),
        ),
    ]
