# Generated by Django 4.2.23 on 2025-08-27 08:27

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aa_bb', '0063_alter_complianceticket_user'),
    ]

    operations = [
        migrations.AlterField(
            model_name='complianceticket',
            name='reason',
            field=models.CharField(choices=[('trpr', 'TRPR Compliance'), ('lawn', 'LAWN Compliance'), ('paps', 'PAP Requirements'), ('afk', 'Inactivity'), ('discord_check', 'User is on discord')], max_length=20),
        ),
    ]
