# Generated by Django 4.2.23 on 2025-08-18 17:22

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aa_bb', '0048_characteraccountstate'),
    ]

    operations = [
        migrations.AddField(
            model_name='userstatus',
            name='clone_status',
            field=models.JSONField(blank=True, default=dict),
        ),
    ]
