# Generated by Django 4.2.20 on 2025-05-09 04:02

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aa_bb', '0016_warmprogress'),
    ]

    operations = [
        migrations.CreateModel(
            name='EntityInfoCache',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('entity_id', models.IntegerField()),
                ('as_of', models.DateTimeField()),
                ('data', models.JSONField()),
                ('updated', models.DateTimeField(auto_now=True)),
            ],
            options={
                'indexes': [models.Index(fields=['entity_id', 'as_of'], name='aa_bb_entit_entity__79afd6_idx'), models.Index(fields=['updated'], name='aa_bb_entit_updated_29e0d0_idx')],
                'unique_together': {('entity_id', 'as_of')},
            },
        ),
    ]
