# Generated by Django 4.2.23 on 2026-01-03 01:54

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aa_bb', '0099_tickettoolconfig_hr_forum_webhook'),
    ]

    operations = [
        migrations.AddField(
            model_name='tickettoolconfig',
            name='use_forum_threads',
            field=models.BooleanField(default=False, help_text='If enabled, compliance tickets will be created as forum threads using the webhook above, even if aadiscordbot is installed.', verbose_name='Use Forum Threads'),
        ),
    ]
