# Generated by Django 4.2.23 on 2025-08-05 11:54

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('aa_bb', '0029_leaverequest_main_character'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='general',
            options={'default_permissions': (), 'managed': False, 'permissions': (('basic_access', 'Can access this app'), ('full_access', 'Can view all main characters'), ('recruiter_access', 'Can view guest main characters only'), ('can_blacklist_characters', 'Can add characters to blacklist'), ('can_access_loa', 'Can access and submit a Leave Of Absence request'), ('can_view_all_loa', 'Can view all Leave Of Absence requests'), ('can_manage_loa', 'Can manage Leave Of Absence requests'))},
        ),
    ]
