# Generated by Django 4.2.23 on 2025-10-31 05:51

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aa_bb', '0077_complianceticket_ticket_id_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='tickettoolconfig',
            name='awox_monitor_enabled',
            field=models.BooleanField(default=False, help_text='Do you want to check for awox kills?'),
        ),
    ]
