# Generated by Django 4.2.23 on 2025-10-30 23:20

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aa_bb', '0076_id_types_last_accessed_frequentcorpchangescache_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='complianceticket',
            name='ticket_id',
            field=models.BigIntegerField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='tickettoolconfig',
            name='char_removed_enabled',
            field=models.BooleanField(default=False, help_text='Do you want to check for removed characters?'),
        ),
        migrations.AlterField(
            model_name='complianceticket',
            name='reason',
            field=models.CharField(choices=[('corp_check', 'Corp Compliance'), ('lawn_check', 'LAWN Compliance'), ('paps_check', 'PAP Requirements'), ('afk_check', 'Inactivity'), ('discord_check', 'User is not on discord'), {'char_removed', 'Character removed'}, {'AWOX kill found', 'awox_kill'}], max_length=20),
        ),
    ]
