# Generated by Django 4.2.21 on 2025-08-03 12:36

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aa_bb', '0020_messages_bigbrotherconfig_are_daily_messages_active_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='messages',
            name='id',
            field=models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID'),
        ),
        migrations.AlterField(
            model_name='messages',
            name='text',
            field=models.TextField(max_length=2000),
        ),
    ]
