# Generated by Django 4.2.21 on 2025-12-23 17:32

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aa_bb', '0094_bigbrotherconfig_corp_compliance_webhook_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='limit_to_main_corp',
            field=models.BooleanField(default=False, help_text='If enabled, automated compliance tickets and compliance notifications will be restricted to members of the primary corporation only. Dashboard visibility and regular background updates will still include all monitored members.', verbose_name='Limit to Main Corporation'),
        ),
    ]
