# Generated by Django 4.2.23 on 2025-08-27 12:55

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('authentication', '0024_alter_userprofile_language'),
        ('aa_bb', '0065_alter_complianceticket_reason_and_more'),
    ]

    operations = [
        migrations.CreateModel(
            name='TicketToolConfig',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('max_months_without_pap_compliance', models.PositiveIntegerField(default=1, help_text='How many months can a person be in corp w/o meeting the pap requirements? (this is a maximum points a user can get, 1 compliant month = plus 1 point, 1 non compliant = minus 1 point. If user has 0 points they get a ticket)')),
                ('corp_check', models.PositiveIntegerField(default=30, help_text='How many days can a user be non compliant on Corp Auth before he should get kicked?')),
                ('corp_check_reason', models.TextField(blank=True, default='# <@&{role}>,<@{namee}>\nSome of your characters are missing a valid token on corp auth, go fix it', help_text='Message to send with {role} and {namee} variables', null=True)),
                ('corp_check_reminder', models.TextField(blank=True, default="<@&{role}>,<@{namee}>, your compliance issue is still unresolved, you have {days} day(s) to fix it or you'll be kicked out.", help_text='Message to send with {role}, {namee} and {days} variables', null=True)),
                ('lawn_check', models.PositiveIntegerField(default=30, help_text='How many days can a user be non compliant on Lawn Auth before he should get kicked?')),
                ('lawn_check_reason', models.TextField(blank=True, default='<@&{role}>,<@{namee}>\nSome of your characters are missing a valid token on lawn auth, go fix it', help_text='Message to send with {role} and {namee} variables', null=True)),
                ('lawn_check_reminder', models.TextField(blank=True, default="<@&{role}>,<@{namee}>, your compliance issue is still unresolved, you have {days} day(s) to fix it or you'll be kicked out.", help_text='Message to send with {role}, {namee} and {days} variables', null=True)),
                ('paps_check', models.PositiveIntegerField(default=45, help_text='How many days can a user not meet the PAP requirements before he should get kicked?')),
                ('paps_check_reason', models.TextField(blank=True, default='<@&{role}>,<@{namee}>, You have fallen below the threshold of months you get to be without meeting the pap requirements, fix it.', help_text='Message to send with {role} and {namee} variables', null=True)),
                ('paps_check_reminder', models.TextField(blank=True, default="Reminder that if you don't meet the PAP quota this month, you will be kicked out, you have {days} day(s) to fix it.", help_text='Message to send with {days} variable', null=True)),
                ('Max_Afk_Days', models.PositiveIntegerField(default=7, help_text='How many days can a user not login to game before he should get a ticket?')),
                ('afk_check', models.PositiveIntegerField(default=7, help_text='How many days can a user not login to game after getting a ticket before he should get a ticket?')),
                ('afk_check_reason', models.TextField(blank=True, default='<@&{role}>,<@{namee}>, you have been inactive for over {days} day(s) without a LoA request, please fix it or submit a LoA request.', help_text='Message to send with {role}, {namee} and {days} variables', null=True)),
                ('afk_check_reminder', models.TextField(blank=True, default="<@&{role}>,<@{namee}>, your compliance issue is still unresolved, you have {days} day(s) to fix it or you'll be kicked out.", help_text='Message to send with {role}, {namee} and {days} variables', null=True)),
                ('discord_check', models.PositiveIntegerField(default=2, help_text='How many days can a user not be on corp discord before he should get kicked?')),
                ('discord_check_reason', models.TextField(blank=True, default="<@&{role}>,<@{namee}>, doesn't have their discord linked on corp auth, try to contact them and if unable, kick them out", help_text='Message to send with {role} and {namee} variables', null=True)),
                ('discord_check_reminder', models.TextField(blank=True, default="<@&{role}>,<@{namee}>'s compliance issue is still unresolved, try to contact them and if unable within {days} day(s) kick them out.", help_text='Message to send with {role}, {namee} and {days} variables', null=True)),
                ('Category_ID', models.CharField(help_text='Category ID to create the tickets in', max_length=255)),
                ('Role_ID', models.CharField(help_text='Role ID to get pinged alongside the non compliant user', max_length=255)),
                # compliance_filter field is added conditionally via add_to_class() in models.py if charlink is installed
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='PapCompliance',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('pap_compliant', models.IntegerField(default=0, help_text='Integer flag or score indicating PAP compliance status')),
                ('user_profile', models.ForeignKey(help_text='The UserProfile this PAP compliance record belongs to', on_delete=django.db.models.deletion.CASCADE, related_name='pap_compliances', to='authentication.userprofile')),
            ],
        ),
    ]
