# Generated by Django 4.2.21 on 2025-12-23 19:51

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aa_bb', '0095_alter_bigbrotherconfig_limit_to_main_corp'),
    ]

    operations = [
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='clone_state_notify',
            field=models.BooleanField(default=True, help_text='Whether to send Alpha/Omega Clone State Change notifications to discord', verbose_name='Clone State Change Discord Notifications'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='clone_notify',
            field=models.BooleanField(default=True, help_text='Whether to send Hostile Jump Clone Location Change notifications to discord', verbose_name='Hostile Jump Clone Location Change Discord Notifications'),
        ),
    ]
