# Generated by Django 4.2.20 on 2025-04-22 14:16

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aa_bb', '0005_alter_bigbrotherconfig_hostile_alliances'),
    ]

    operations = [
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='pingroleID',
            field=models.CharField(default=0, help_text='Input the role ID you want pinged when people need to investigate', max_length=255, null=True),
        ),
    ]
